cudaExternalSemaphoreHandleType

Enum cudaExternalSemaphoreHandleType 

#[non_exhaustive]
#[repr(u32)]
pub enum cudaExternalSemaphoreHandleType { cudaExternalSemaphoreHandleTypeOpaqueFd = 1, cudaExternalSemaphoreHandleTypeOpaqueWin32 = 2, cudaExternalSemaphoreHandleTypeOpaqueWin32Kmt = 3, cudaExternalSemaphoreHandleTypeD3D12Fence = 4, cudaExternalSemaphoreHandleTypeD3D11Fence = 5, cudaExternalSemaphoreHandleTypeNvSciSync = 6, cudaExternalSemaphoreHandleTypeKeyedMutex = 7, cudaExternalSemaphoreHandleTypeKeyedMutexKmt = 8, cudaExternalSemaphoreHandleTypeTimelineSemaphoreFd = 9, cudaExternalSemaphoreHandleTypeTimelineSemaphoreWin32 = 10, }
External semaphore handle types

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


cudaExternalSemaphoreHandleTypeOpaqueFd = 1

Handle is an opaque file descriptor



cudaExternalSemaphoreHandleTypeOpaqueWin32 = 2

Handle is an opaque shared NT handle



cudaExternalSemaphoreHandleTypeOpaqueWin32Kmt = 3

Handle is an opaque, globally shared handle



cudaExternalSemaphoreHandleTypeD3D12Fence = 4

Handle is a shared NT handle referencing a D3D12 fence object



cudaExternalSemaphoreHandleTypeD3D11Fence = 5

Handle is a shared NT handle referencing a D3D11 fence object



cudaExternalSemaphoreHandleTypeNvSciSync = 6

Opaque handle to NvSciSync Object



cudaExternalSemaphoreHandleTypeKeyedMutex = 7

Handle is a shared NT handle referencing a D3D11 keyed mutex object



cudaExternalSemaphoreHandleTypeKeyedMutexKmt = 8

Handle is a shared KMT handle referencing a D3D11 keyed mutex object



cudaExternalSemaphoreHandleTypeTimelineSemaphoreFd = 9

Handle is an opaque handle file descriptor referencing a timeline semaphore



cudaExternalSemaphoreHandleTypeTimelineSemaphoreWin32 = 10

Handle is an opaque handle file descriptor referencing a timeline semaphore